
.. include:: ../readme.rst
.. |Splines| replace:: :doc:`Splines<math>`
.. |Comparisons| replace:: :doc:`Comparisons<compare>`
.. |1D example| replace:: :doc:`1D example<auto_examples/1d-lsq>`
.. |2D example| replace:: :doc:`2D example<auto_examples/2d-lsq>`


.. toctree::
   :maxdepth: 1
   :hidden:

   math
   compare
   api
   auto_examples/index
   auto_benchmarks/index
